BPH PAL (Bluepill Hat Protocol Abstraction Layer)
================================

## Description

This is a python interface to talk to the bluepill hat.  It provides helpers for bootloading PHiLIP.
